@@ -4,7 +4,7 @@ use Moo;
 use MooX::LazierAttributes;
 
 attributes (
-    one      => [ 'rw', 10 ],    
+    one      => [ 10 ],    
     two      => [ ro, [qw/one two three/] ],    
     three    => [ 'ro', { one => 'two' } ],    
     four     => [ 'ro', 'a default value' ],
@@ -16,6 +16,7 @@ attributes (
     ten      => [ 'rw', {}],
     [qw/eleven twelve thirteen/] => [ro, 'test this'],
     fourteen => [ rw, nan, { bld, clr, lzy } ],
+    fifthteen => [ sub { { correct => 'way' } } ],
 );
 
 sub _build_fourteen {
